function [BlobImage, NumberOfBlobs] = SearchBlobs(Image)
//////////////////////////////////////////////////////////////////////////// 
// IPD - Image Processing Design Toolbox
//
// Copyright (c) by Dr. Eng. (J) Harald Galda, 2009
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
////////////////////////////////////////////////////////////////////////////
 
 
 // Input and output parameters are checked.
 
 [NumberOfOutputs NumberOfInputs] = argn();
 
 if NumberOfInputs ~= 1
  
  error('Wrong number of input parameters.');
  
 end;
  
 CheckBooleanMatrix(Image, 'Image');
 
 if (NumberOfOutputs == 0) | (NumberOfOutputs > 2)
  
  error('Wrong number of output parameters.');
  
 end;

 // The blobs are searched by the C++ function SearchObjects.
 
 [NumberOfRows, NumberOfColumns] = size(Image);
 
 BlobImageAsDouble = call('SearchObjects', ...
                          bool2s(Image), ...
                          1, ...
                          'd', ...
                          NumberOfColumns, ...
                          2, ...
                          'i', ...
                          NumberOfRows, ...
                          3, ...
                          'i', ...
                          'out', ...
                          [NumberOfRows, NumberOfColumns], ...
                          4, ...
                          'd');
 
 // Output parameters are set.
 
 BlobImage = uint32(BlobImageAsDouble);
 
 if NumberOfOutputs == 2 then
  
  NumberOfBlobs = max(BlobImage(:));
  
 end;
 
endfunction

