function FigureHandle = ShowImage(Image, Title, ColorMap)
//////////////////////////////////////////////////////////////////////////// 
// IPD - Image Processing Design Toolbox
//
// Copyright (c) by Dr. Eng. (J) Harald Galda, 2009
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
////////////////////////////////////////////////////////////////////////////
 
 // Parameters are checked.
 
 [NumberOfOutputs NumberOfInputs] = argn();

 // There must be at least two input parameters and at most three.
 
 if (NumberOfInputs < 2) | (NumberOfInputs > 3) then
  
  error('Wrong number of input parameters.');
  
 end;
 
 // Image must be a 2D matrix.
 
 CheckMatrix(Image, 'Image');

 // Title must be a string.
 
 CheckString(Title, 'Title');
  
 // ColorMap is optional. If ColorMap is specified, it must be a matrix with 
 // three columns. If ColorMap is not specified, it is initialized to gray
 // color map.
 
 if NumberOfInputs == 3
 
  if length(size(ColorMap)) == 2 then
   
   if size(ColorMap, 2) ~= 3
    
    error('ColorMap must be a 2D matrix with exactly three columns.');
    
   end;
          
  else
  
   error('ColorMap must be a 2D matrix with exactly three columns.');
  
  end;
 
 else
 
  MaximumGrayValue = 256;
  
  ColorMap = graycolormap(MaximumGrayValue);
 
 end;
 
 FigureHandle = gcf();
 
 FigureHandle.color_map = ColorMap;
 
 FigureHandle.figure_size = [size(Image, 2), size(Image, 1)];
 
 FigureHandle.axes_size = FigureHandle.figure_size;
 
 FigureHandle.figure_name = Title;
 
 if type(Image) ~= TYPE_BOOLEAN then
 
  Matplot(Image);
 
 else
 
  Matplot(255 * bool2s(Image));
 
 end;
 
 Diagram = gca();
 
 Diagram.axes_visible = ['off', 'off', 'off'];
 
 Diagram.tight_limits = 'on';
 
 Diagram.axes_reverse = ['off' 'off' 'off'];
 
 Diagram.margins = [0, 0, 0, 0];
  
endfunction

