function ResultImage = TopHat(Image, StructureElement)
//////////////////////////////////////////////////////////////////////////// 
// IPD - Image Processing Design Toolbox
//
// Copyright (c) by Dr. Eng. (J) Harald Galda, 2009
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
////////////////////////////////////////////////////////////////////////////

 // Input and output parameters are checked.
 
 [NumberOfOutputs NumberOfInputs] = argn();
 
 if NumberOfInputs ~= 2 then
  
  error('Wrong number of input parameters.');
  
 end;
 
 CheckMatrix(Image, 'Image');
 
 if type(Image) == TYPE_BOOLEAN then
  
  Image = bool2s(Image);
  
 end;

 CheckStructureElement(StructureElement, 'StructureElement');
  
 if NumberOfOutputs ~= 1
  
  error('Wrong number of output parameters.');
  
 end;

 [NumberOfRows, NumberOfColumns] = size(Image);
 
 if type(Image) == TYPE_DOUBLE then
  
  PassedImage = Image;
  
 else
  
  PassedImage = im2double(Image);
  
 end;

 FilteredImage = call('MorphologicalFilter', ...
                      PassedImage, ...
                      1, ...
                      'd', ...
                      NumberOfColumns, ...
                      2, ...
                      'i', ...
                      NumberOfRows, ...
                      3, ...
                      'i', ...
                      FILTER_TOP_HAT, ...
                      4, ...
                      'i', ...
                      StructureElement.Width, ...
                      5, ...
                      'i', ...
                      StructureElement.Height, ...
                      6, ...
                      'i', ...
                      bool2s(StructureElement.Data), ...
                      7, ...
                      'd', ...
                      'out', ...
                      [NumberOfRows, NumberOfColumns], ...
                      8, ...
                      'd'); 

 select type(Image)
 
  case TYPE_BOOLEAN
   
   ResultImage = (FilteredImage > 0);
   
  case TYPE_DOUBLE
   
   ResultImage = FilteredImage;
   
  case TYPE_INT
   
   select typeof(Image)
    
    case 'uint8'
     
     ResultImage = im2uint8(FilteredImage);
     
    case 'uint16'
     
     ResultImage = im2uint16(FilteredImage);
     
    case 'uint32'
     
     ResultImage = uint32((2 ^ 32 - 1) * FilteredImage);
     
    else
     
     error('Internal error occured in DilateImage.');
     
   end;
  
 end;

endfunction

