//////////////////////////////////////////////////////////////////////////// 
// IPD - Image Processing Design Toolbox
//
// Copyright (c) by Dr. Eng. (J) Harald Galda, 2009
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
////////////////////////////////////////////////////////////////////////////


#include "IPD.h"


// This function creates a list of pixel indices for each object in a blob image and stores
// it in a matrix. This matrix has as many columns as BlobImage contains objects and as ma-
// ny rows as the biggest blob has pixels. If an object has n pixels, the first n elements 
// of the corresponding column contain the pixel indices and all other elements of the co-
// lumn are zero. This function is intended to be called by Scilab. 
// Calling syntax in Scilab:
// PixelIndexMatrix = call('CreatePixelIndexList', ...
//                         BlobImage, ...
//                         1, ...
//                         'd', ...
//                         NumberOfPixels, ...
//                         2, ...
//                         'i', ...
//                         NumberOfObjects, ...
//                         3, ...
//                         'i', ...
//                         MaxArea, ...
//                         4, ...
//                         'i', ...
//                         'out', ...
//                         [MaxArea NumberOfObjects], ...
//                         5, ...
//                         'd')
extern "C" __declspec(dllexport)
int CreatePixelIndexList(double* BlobImage, 
                         TUInt* NumberOfPixels, 
                         TULong* NumberOfObjects, 
                         TULong* MaxArea, 
                         double* PixelIndexMatrix)
{
 // PixelIndexMatrix is initialized.
 
 TULong NumberOfElements = (*NumberOfObjects) * (*MaxArea);

 for(TULong n = 0; n < NumberOfElements; n++)
 {
  PixelIndexMatrix[n] = 0;
 } // for

 // For each column of PixelIndexMatrix an index to the next element is initialized.
 TVector NextElement(*NumberOfObjects, 0);

 // The pixel indices are transferred to PixelIndexMatrix.
 for(TULong n = 0; n < (*NumberOfPixels); n++)
 {
  if(BlobImage[n] > 0)
  {
   TULong BlobIndex = TULong(BlobImage[n]) - 1;

   PixelIndexMatrix[BlobIndex * (*MaxArea) + NextElement[BlobIndex]] = n + 1;

   NextElement[BlobIndex]++;
  } // if
 } // for

 return 0;
} // CreatePixelList
