//////////////////////////////////////////////////////////////////////////// 
// IPD - Image Processing Design Toolbox
//
// Copyright (c) by Dr. Eng. (J) Harald Galda, 2009
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
////////////////////////////////////////////////////////////////////////////

#ifndef FILTER_H
#define FILTER_H

#include "IPD.h"


// CFilter is an abstract class that defines image filter operations. When an object of 
// a subclass of CFilter is initiated, the number of columns, number of rows and a pointer
// to an array containing the gray values of the filter are specified. The gray values are
// not copied so the memory of this array must not be released before as long as the filter
// object lives. The filter can be applied to any source and destination image using the 
// function FilterImage().

class CFilter
{
 public:

  CFilter(TUInt NumberOfColumns, TUInt NumberOfRows, const double* const Values);

  virtual ~CFilter(){};

  virtual void FilterImage(TUInt ImageWidth, 
                           TUInt ImageHeight, 
                           const double* const Source, 
                           double* Destination);

 protected:

  typedef vector<double> TGrayValueList;

  typedef vector<int> TOffsetList;

  virtual double SelectGrayValue(const TGrayValueList& GrayValues) = 0;

  TUInt SubscriptsToIndex(TUInt ImageHeight, TUInt Column, TUInt Row);

  TUInt m_NumberOfElements;

  const double* const m_Values;
  
  TOffsetList m_ColumnOffsets;

  TOffsetList m_RowOffsets;

 private:

  CFilter():m_Values(NULL){};

  CFilter(const CFilter&):m_Values(NULL){};
}; // CFilter

#endif